@@ -1,5 +1,5 @@
 from samtranslator.model import PropertyType, Resource
-from samtranslator.model.types import is_type, is_str, list_of
+from samtranslator.model.types import is_type, is_str, list_of, one_of
 from samtranslator.model.intrinsics import ref
 
 
@@ -9,7 +9,7 @@ class NestedStack(Resource):
     property_types = {
         'TemplateURL': PropertyType(True, is_str()),
         'Parameters': PropertyType(False, is_type(dict)),
-        'NotificationARNs': PropertyType(False, list_of(is_str())),
+        'NotificationARNs': PropertyType(False, list_of(one_of(is_str(), is_type(dict)))),
         'Tags': PropertyType(False, list_of(is_type(dict))),
         'TimeoutInMinutes': PropertyType(False, is_type(int))
     }
